@@ -1,5 +1,5 @@
 /*
- *  Copyright 2013-2014  Andreas Cord-Landwehr <cordlandwehr@kde.org>
+ *  Copyright 2013-2016  Andreas Cord-Landwehr <cordlandwehr@kde.org>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -38,7 +38,7 @@ class LIBLEARNERPROFILE_EXPORT Learner : public QObject
     Q_OBJECT
     Q_PROPERTY(QString name READ name WRITE setName NOTIFY nameChanged)
     Q_PROPERTY(int id READ identifier WRITE setIdentifier NOTIFY identifierChanged)
-    Q_PROPERTY(QString imageUrl READ imageUrl NOTIFY imageUrlChanged)
+    Q_PROPERTY(QString imageUrl READ imageUrl NOTIFY imageChanged)
     Q_PROPERTY(QList<LearnerProfile::LearningGoal*> goals READ goals NOTIFY goalCountChanged)
 
 public:
@@ -52,26 +52,34 @@ public:
         Language = 1
     };
 
-    explicit Learner(QObject *parent = 0);
+    explicit Learner(QObject *parent = nullptr);
     ~Learner();
 
     QString name() const;
     void setName(const QString &name);
+    /**
+     * \return URL to image
+     * \note since it is a local file the path begins with "file://"
+     */
     QString imageUrl() const;
+    Q_INVOKABLE void clearImage();
     void importImage(const QString &path);
     int identifier() const;
     void setIdentifier(int identifier);
+    /**
+     * \return list of all learning goals of learner
+     */
     QList<LearningGoal *> goals() const;
     Q_INVOKABLE void addGoal(LearnerProfile::LearningGoal *goal);
     Q_INVOKABLE void removeGoal(LearnerProfile::LearningGoal *goal);
     Q_INVOKABLE bool hasGoal(LearnerProfile::LearningGoal *goal) const;
-    void setActiveGoal(LearningGoal *goal);
+    void setActiveGoal(LearnerProfile::LearningGoal *goal);
     Q_INVOKABLE void setActiveGoal(LearnerProfile::Learner::Category category, const QString &identifier);
     Q_INVOKABLE LearnerProfile::LearningGoal * activeGoal(LearnerProfile::Learner::Category category) const;
 
 Q_SIGNALS:
     void nameChanged();
-    void imageUrlChanged();
+    void imageChanged();
     void identifierChanged();
     void goalAboutToBeAdded(LearningGoal*,int);
     void goalAdded();
