@@ -27,14 +27,14 @@
 
 #include "artikulate_debug.h"
 #include <QTemporaryFile>
-#include <sys/stat.h>
 
 Phrase::Phrase(QObject *parent)
     : QObject(parent)
     , m_type(Phrase::AllTypes)
     , m_editState(Unknown)
-    , m_trainingState(Untrained)
     , m_unit(nullptr)
+    , m_trainingProgress(0)
+    , m_skipCounter(0)
     , m_excludedFromUnit(false)
 {
     connect(this, &Phrase::idChanged, this, &Phrase::modified);
@@ -203,17 +203,6 @@ void Phrase::setEditState(const QString &stateString)
     return;
 }
 
-Phrase::TrainingState Phrase::trainingState() const
-{
-    return m_trainingState;
-}
-
-void Phrase::setTrainingState(Phrase::TrainingState state)
-{
-    m_trainingState = state;
-    emit trainingStateChanged();
-}
-
 Unit * Phrase::unit() const
 {
     return m_unit;
@@ -282,6 +271,42 @@ void Phrase::setExcluded(bool excluded)
     emit excludedChanged();
 }
 
+int Phrase::progress() const
+{
+    return m_trainingProgress;
+}
+
+void Phrase::setProgress(int value)
+{
+    if (m_trainingProgress == value) {
+        return;
+    }
+    m_trainingProgress = value;
+    emit progressChanged();
+}
+void Phrase::updateProgress(Phrase::Progress progress)
+{
+    // logic of progress computation:
+    // a) if skipped 3 times in a row, decrease progress
+    // b) if done and skipped less than two times in a row, increase progress
+    if (progress == Progress::Done) {
+        m_skipCounter = 0;
+        if (m_trainingProgress < 3) {
+            ++m_trainingProgress;
+            emit progressChanged();
+        }
+        return;
+    }
+    if (progress == Progress::Skip) {
+        ++m_skipCounter;
+        if (m_skipCounter > 2 && m_trainingProgress > 0) {
+            --m_trainingProgress;
+            emit progressChanged();
+        }
+        return;
+    }
+}
+
 QList<Phoneme *> Phrase::phonemes() const
 {
     return m_phonemes;
